@@ -121,7 +121,7 @@ def build_module(source_files, options=[], skip=[], only=[], module_name=None):
         dst_sources.append(dst)
 
         base, ext = os.path.splitext(dst)
-        if ext in (".f90", ".f", ".c", ".pyf"):
+        if ext in (".f90", ".f95", ".f", ".c", ".pyf"):
             f2py_sources.append(dst)
 
     assert f2py_sources
@@ -332,7 +332,7 @@ def build_meson(source_files, module_name=None, **kwargs):
     # compiler stack is on the CI
     try:
         backend.compile()
-    except:
+    except subprocess.CalledProcessError:
         pytest.skip("Failed to compile module")
 
     # Import the compiled module
